@@ -16,6 +16,20 @@ class CsvRowDataGenerator:
         self.data_files_contents = data_files_contents
         self.columns = columns
 
+    def _get_value_for_row_from_column(self, column):
+        try:
+            (
+                _column_values_list,
+                _column_values_list_item_count,
+            ) = self.data_files_contents[column["datafile"]]
+        except KeyError as key_err:
+            raise DummyFileGeneratorException(
+                f"Cannot find corresponding data_file for "
+                f'column {column.get("column_name")}, '
+                f"Key Error: {key_err}"
+            )
+        return _column_values_list[randint(0, _column_values_list_item_count - 1)]
+
     def generate_header_row(self):
         """
         generate header row method
@@ -31,19 +45,7 @@ class CsvRowDataGenerator:
         row = []
 
         for column in self.columns:
-            try:
-                (
-                    _column_values_list,
-                    _column_values_list_item_count,
-                ) = self.data_files_contents[column["datafile"]]
-            except KeyError as key_err:
-                raise DummyFileGeneratorException(
-                    f"Cannot find corresponding data_file for "
-                    f'column {column.get("column_name")}, '
-                    f"Key Error: {key_err}"
-                )
-
-            value = _column_values_list[randint(0, _column_values_list_item_count - 1)]
+            value = self._get_value_for_row_from_column(column=column)
             row.append(value)
 
         return row
@@ -61,13 +63,26 @@ class FlatRowDataGenerator:
         :param whitespace_count:
         :return:
         """
-        whitespace_char = " "
-        return whitespace_count * whitespace_char
+        return whitespace_count * " "
 
     def __init__(self, data_files_contents, columns):
         self.data_files_contents = data_files_contents
         self.columns = columns
 
+    def _get_value_for_row_from_column(self, column):
+        try:
+            (
+                _column_values_list,
+                _column_values_list_item_count,
+            ) = self.data_files_contents[column["datafile"]]
+        except KeyError as key_err:
+            raise DummyFileGeneratorException(
+                f"Cannot find corresponding data_file for "
+                f'column {column.get("column_name")}, '
+                f"Key Error: {key_err}"
+            )
+        return _column_values_list[randint(0, _column_values_list_item_count - 1)]
+
     def generate_header_row(self):
         """
         generate header row method
@@ -92,18 +107,7 @@ class FlatRowDataGenerator:
         row = []
 
         for column in self.columns:
-            try:
-                (
-                    _column_values_list,
-                    _column_values_list_item_count,
-                ) = self.data_files_contents[column["datafile"]]
-            except KeyError as key_err:
-                raise DummyFileGeneratorException(
-                    f"Cannot find corresponding data_file for "
-                    f'column {column.get("column_name")}, '
-                    f"Key Error: {key_err}"
-                )
-            value = _column_values_list[randint(0, _column_values_list_item_count - 1)]
+            value = self._get_value_for_row_from_column(column=column)
             whitespace_count = column["column_len"] - len(value)
             row.append(
                 value + FlatRowDataGenerator._whitespace_value_filler(whitespace_count)
@@ -121,6 +125,20 @@ class DictRowDataGenerator:
         self.data_files_contents = data_files_contents
         self.columns = columns
 
+    def _get_value_for_row_from_column(self, column):
+        try:
+            (
+                _column_values_list,
+                _column_values_list_item_count,
+            ) = self.data_files_contents[column["datafile"]]
+        except KeyError as key_err:
+            raise DummyFileGeneratorException(
+                f"Cannot find corresponding data_file for "
+                f'column {column.get("column_name")}, '
+                f"Key Error: {key_err}"
+            )
+        return _column_values_list[randint(0, _column_values_list_item_count - 1)]
+
     def generate_header_row(self):
         """
         generate header row method
@@ -137,20 +155,30 @@ class DictRowDataGenerator:
         """
         row = dict()
 
-        for column in self.columns:
-            try:
-                (
-                    _column_values_list,
-                    _column_values_list_item_count,
-                ) = self.data_files_contents[column["datafile"]]
-            except KeyError as key_err:
-                raise DummyFileGeneratorException(
-                    f"Cannot find corresponding data_file for "
-                    f'column {column.get("column_name")}, '
-                    f"Key Error: {key_err}"
-                )
-            value = _column_values_list[randint(0, _column_values_list_item_count - 1)]
-            row[column["column_name"]] = value
+        def _set_row_data(cols, context_col=None):
+            for column in cols:
+                if isinstance(column.get("__array_columns"), list):
+                    row[column["column_name"]] = []
+                    _set_row_data(
+                        cols=column["__array_columns"],
+                        context_col=column["column_name"],
+                    )
+                    continue
+                if column.get("columns"):
+                    value = dict()
+                    for nested_col in column.get("columns"):
+                        value[
+                            nested_col["column_name"]
+                        ] = self._get_value_for_row_from_column(column=nested_col)
+                else:
+                    value = self._get_value_for_row_from_column(column=column)
+
+                if context_col:
+                    row[context_col].append(value)
+                else:
+                    row[column["column_name"]] = value
+
+        _set_row_data(cols=self.columns)
 
         return row
 
